@@ -10,6 +10,12 @@ class WebsiteSubscription(WebsiteSubscription):
         values = super(WebsiteSubscription, self).fill_values(values, is_company, logged, load_from_user=False)
         sub_req_obj = request.env['subscription.request']
         fields_desc = sub_req_obj.sudo().fields_get(['join_commission', 'discovery_channel'])
-        values['commissions'] = fields_desc['join_commission']['selection']
-        values['channels'] = fields_desc['discovery_channel']['selection']
+        company = request.env['res.company']._company_default_get()
+        values.update({
+            'commissions': fields_desc['join_commission']['selection'],
+            'channels': fields_desc['discovery_channel']['selection'],
+            'display_sepa': company.display_sepa_approval,
+            'sepa_required': company.sepa_approval_required,
+            'sepa_text': company.sepa_approval_text
+        })
         return values
